@@ -84,15 +84,15 @@ sub api_call ( $self, @args ) {
 }
 
 sub nginx_cfg ($self) {
-    my $www_storage = $ENV->share->get_storage('www');
+    my $www_storage = $ENV->{share}->get_storage('www');
 
     my $params = {
         name              => lc( ref $self ) =~ s/::/-/smgr,
         data_dir          => $ENV->{DATA_DIR},
-        www_root_dir      => $www_storage ? $www_storage->[0] : undef,      # TODO
-        default_server    => 1,                                             # generate default server config
-        nginx_default_key => $ENV->share->get('/data/nginx/default.key'),
-        nginx_default_pem => $ENV->share->get('/data/nginx/default.pem'),
+        www_root_dir      => $www_storage ? $www_storage->[0] : undef,       # TODO
+        default_server    => 1,                                              # generate default server config
+        nginx_default_key => $ENV->{share}->get('data/nginx/default.key'),
+        nginx_default_pem => $ENV->{share}->get('data/nginx/default.pem'),
         upstream          => $self->{app_cfg}->{server}->{listen},
     };
 
