@@ -8,9 +8,9 @@ use Pcore::Core::Dump::Dumper;
 
 sub dump {    ## no critic qw[Subroutines::ProhibitBuiltinHomonyms]
     my %args = (
-        color       => 1,
-        indent      => 4,
-        dump_method => 'TO_DUMP',
+        color  => 1,
+        tags   => 1,
+        indent => 4,
         @_[ 1 .. $#_ ],
     );
 
